aboutsummaryrefslogtreecommitdiff
path: root/sysdeps/unix/sysv/linux/hppa/bits
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/unix/sysv/linux/hppa/bits')
-rw-r--r--sysdeps/unix/sysv/linux/hppa/bits/types/struct_semid_ds.h (renamed from sysdeps/unix/sysv/linux/hppa/bits/sem-pad.h)24
1 files changed, 17 insertions, 7 deletions
diff --git a/sysdeps/unix/sysv/linux/hppa/bits/sem-pad.h b/sysdeps/unix/sysv/linux/hppa/bits/types/struct_semid_ds.h
index ee0332325b..d4c50b5ef8 100644
--- a/sysdeps/unix/sysv/linux/hppa/bits/sem-pad.h
+++ b/sysdeps/unix/sysv/linux/hppa/bits/types/struct_semid_ds.h
@@ -1,5 +1,5 @@
-/* Define where padding goes in struct semid_ds. HPPA version.
- Copyright (C) 2018-2020 Free Software Foundation, Inc.
+/* HPPA implementation of the semaphore struct semid_ds
+ Copyright (C) 1995-2020 Free Software Foundation, Inc.
This file is part of the GNU C Library.
The GNU C Library is free software; you can redistribute it and/or
@@ -17,10 +17,20 @@
<https://www.gnu.org/licenses/>. */
#ifndef _SYS_SEM_H
# error "Never use <bits/sem-pad.h> directly; include <sys/sem.h> instead."
#endif
-#include <bits/timesize.h>
-
-#define __SEM_PAD_AFTER_TIME 0
-#define __SEM_PAD_BEFORE_TIME (__TIMESIZE == 32)
+/* Data structure describing a set of semaphores. */
+#if __TIMESIZE == 32
+struct semid_ds
+{
+ struct ipc_perm sem_perm; /* operation permission struct */
+ __syscall_ulong_t __glibc_reserved1;
+ __time_t sem_otime; /* last semop() time */
+ __syscall_ulong_t __glibc_reserved2;
+ __time_t sem_ctime; /* last time changed by semctl() */
+ __syscall_ulong_t sem_nsems; /* number of semaphores in set */
+ __syscall_ulong_t __glibc_reserved3;
+ __syscall_ulong_t __glibc_reserved4;
+};
+#endif
@@ -17,10 +17,20 @@
<https://www.gnu.org/licenses/>. */
#ifndef _SYS_SEM_H
-# error "Never use <bits/sem-pad.h> directly; include <sys/sem.h> instead."
+# error "Never include <bits/types/struct_semid_ds.h> directly; use <sys/sem.h> instead."
#endif